@@ -1,7 +1,7 @@
 package Module::Path::More;
 
-our $DATE = '2014-12-29'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2015-04-15'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010001;
 use strict;
@@ -202,7 +202,7 @@ Module::Path::More - Get path to locally installed Perl module
 
 =head1 VERSION
 
-This document describes version 0.27 of Module::Path::More (from Perl distribution Module-Path-More), released on 2015-12-29.
+This document describes version 0.28 of Module::Path::More (from Perl distribution Module-Path-More), released on 2015-04-15.
 
 =head1 SYNOPSIS
 
@@ -238,10 +238,27 @@ C<.pm> file. If a file defines multiple packages, this won't work. This also
 won't find any modules that are being loaded in some special way, for example
 using a code reference in C<@INC>, as described in C<require> in L<perlfunc>.
 
+To check whether a module is available/loadable, it's generally better to use
+something like:
+
+ if (eval { require Some::Module; 1 }) {
+     # module is available
+ }
+
+because this works with fatpacking or any other C<@INC> hook that might be
+installed. If you use:
+
+ if (module_path(module => "Some::Module")) {
+     # module is available
+ }
+
+then it only works if the module is locatable in the filesystem. But on the
+other hand this method can avoid actual loading of the module.
+
 =head1 FUNCTIONS
 
 
-=head2 module_path(%args) -> array|str
+=head2 module_path(%args) -> str|array[str]
 
 Get path to locally installed Perl module.
 
@@ -287,12 +304,10 @@ Module name to search.
 
 =back
 
-Return value:
-
- (any)
+Return value:  (str|array[str])
 
 
-=head2 pod_path(%args) -> array|str
+=head2 pod_path(%args) -> str|array[str]
 
 Get path to locally installed POD.
 
@@ -318,9 +333,7 @@ Module name to search.
 
 =back
 
-Return value:
-
- (any)
+Return value:  (str|array[str])
 
 =head1 SEE ALSO
 
@@ -337,7 +350,7 @@ or resolving symlinks will sometimes fail or expose filesystem quirks that we
 might not want to deal with at all. However, if you want to do abs_path, you can
 do so by setting C<abs> option to true.
 
-Command-like utility is not included in this distribution, unlike L<mpath> in
+Command-line utility is not included in this distribution, unlike L<mpath> in
 C<Module-Path>. However, you can use L<pmpath> from C<App-PMUtils> which uses
 this module.
 
@@ -361,7 +374,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Module-Pat
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Alt-Module-Path-SHARYANTO>.
+Source repository is at L<https://github.com/perlancar/perl-Module-Path-More>.
 
 =head1 BUGS
 
@@ -377,7 +390,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
